@@ -15,7 +15,7 @@ use HTML::TokeParser::Simple;
 use B::Deparse;
 
 use vars qw( $VERSION @EXPORT %munge_map );
-$VERSION = '0.45';
+$VERSION = '0.47';
 @EXPORT = qw( &shell );
 
 =head1 NAME
@@ -108,7 +108,8 @@ sub init {
 		verbose => 0,
   };
   # Install the request dumper :
-  $self->{request_wrapper} = wrap *LWP::UserAgent::request,
+  $self->{request_wrapper} = wrap 'LWP::UserAgent::request',
+      #pre => sub { printf STDERR "Dumping? %s\n",$self->option("dumprequests"); $self->request_dumper($_[1]) if $self->option("dumprequests"); },
       pre => sub { $self->request_dumper($_[1]) if $self->option("dumprequests"); },
       post => sub {
                     $self->response_dumper($_[-1]) if $self->option("dumpresponses");
@@ -163,7 +164,10 @@ circular reference. This method does this.
 
 sub release_agent {
   my ($self) = @_;
+  use Data::Dumper;
+  warn Dumper $self;
   undef $self->{request_wrapper};
+  undef $self->{redirect_ok_wrapper};
   $self->{agent} = undef;
 };
 
@@ -1350,12 +1354,14 @@ sub run_auth {
     my ($authority, $realm, $user, $password);
     if (scalar @_ == 2) {
       unless ($self->agent->res) {
-        print "Can't guess authentification elements without a request.";
+        print "Can't guess authentification elements without a request or a realm.";
         print "Use the four parameter version instead.";
         return;
       };
 
       ($user,$password) = @_;
+      $password = "" if not defined $password;
+
       my $code = sub {
           if ($self->agent->res->www_authenticate =~ /\brealm=(['"]?)(.*)\1/) {
             $realm = $2
@@ -2054,7 +2060,7 @@ invocation of the shell like with CPAN :
 
 This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
-Copyright (C) 2002,2003 Max Maischein
+Copyright (C) 2002,2008 Max Maischein
 
 =head1 AUTHOR
 
